//: SimpleQuery

import com.hp.turboimage.*;
import java.rmi.*;
import java.io.*;
import java.util.zip.*;

public class SimpleQuery implements Serializable {

    // Booleans that control how much this bean is responsible for doing
    boolean openDatabase   = false;
    boolean remoteDatabase = false;
    boolean openDataset    = false;
    boolean displayEntries = false;

    // Bean attributes
    String basename        = "rootfile.group.account";
    String setname         = "setname";
    
    Database db;
    String   remoteHost = "host.domain.com";
    String   password   = ";";
    Dataset  ds;
    Entry[]  entries;
    String   itemList;
    String   keyName;
    Object   keyValue;
    
    // No-argument constructor is required for all beans
    public SimpleQuery() { }

    // First, we have methods to set the boolean 'bean controls'
    public void setOpenDB(boolean b)   { openDatabase = b; }
    public void setOpenDS(boolean b)   { openDataset  = b; }
    public void setRemoteDB(boolean b) { remoteDatabase = b; }
    public void setDisplay(boolean b)  { displayEntries = b; }

    // Next, we have typical bean methods to set other attributes
    public void setBasename(String base) { basename = base; }
    public void setSetname(String set) { setname = set; }
    public void setPassword(String pass) { password = pass; }
    public void setDatabase(Database database) { db = database; }
    public void setRemoteHost(String host) { remoteHost = host; }
    public void setDataset(Dataset s) { ds = s; }
    
    // And bean methods to return attribute values
    public boolean getOpenDB() { return openDatabase; }
    public boolean getOpenDS() { return openDataset; }
    public boolean getRemoteDB() { return remoteDatabase; }
    public boolean getDisplay()  { return displayEntries; }
    public String getBasename()  { return basename; }
    public String getSetname()   { return setname; }
    public String getPassword()  { return password; }
    public Database getDatabase() { return db; }
    public String getRemoteHost() { return remoteHost; }
    public Dataset getDataset()   { return ds; }
    

    public void execute() throws java.io.IOException {
        TurboIMAGEServer dbfactory = null;
        
        // Start the security manager
        System.setSecurityManager(new RMISecurityManager());

        // Connect to the TurboIMAGEFactory object
        try {
           dbfactory = (TurboIMAGEServer) Naming.lookup( 
                       "rmi://" + remoteHost + "/TurboIMAGEFactory");
           System.out.println("Connected to server.");
        } catch (Exception e) { System.out.println(e); }
        
        // If we're responsible for opening the database, do it
        if (openDatabase) {
            try {
               db = dbfactory.getDatabase(basename);
               db.setPassword(password);
               db.openSharedRead();
               System.out.println("Database is open.");
            } catch (Exception e) { System.out.println(e); }
        }
        
        // If we're responsible for getting a dataset handle, do it
        if (openDataset) {
            try {
               ds = dbfactory.getDataset(db, "EMPDTL");
               System.out.println("Dataset created.");
            } catch (Exception e) { System.out.println(e); }
        }
        
        // Execute the query
        try {
        } catch (Exception e) { System.out.println(e); }
        
        // If we're supposed to display the results, do so
        if (displayEntries) {
            try {
                Entry detailEntry = dbfactory.getEntry(db, ds);
                System.out.println("Entry created.");
                detailEntry.allElements();
                System.out.println("Entry initialized.");

                // Read the dataset and display results 
                while(ds.readSerial(detailEntry)){
                   System.out.println(detailEntry.getValue("EMPLOYEE-NUMBER") 
                       + " " + detailEntry.getValue("FIRST-NAME")
                       + " " + detailEntry.getValue("LAST-NAME")       );
                }
                System.out.println("No more entries in dataset.");
            } catch (Exception e) { System.out.println(e); }
        }
        
        // fire 'finished' event so other beans can be triggered
        
        // Hang around until user finished looking
        System.out.println("Press return to continue . . .");
        System.in.read();
       
    }   
 }



