//: EmpDetailClient.java

import com.hp.turboimage.*;

import java.io.*;
import java.net.*;
import java.rmi.RemoteException;

/** This class provides an example of how to call the 
 *  Java TurboIMAGE library routines.  This class will open
 *  a database and read a dataset serially, displaying each 
 *  record.  At this point, only those functions required to
 *  support this program are actually implemented by the
 *  TurboIMAGE library.<p>
 *
 * @author Mike Yawn
 * @version 2.1 March 1998
 */
public class EmpDetailClient {

   public static void main(String argv[]) 
                      throws RemoteException, IMAGEException {
      EmployeeDB     empDB       = null;
      EmpDetailDS    empDetail   = null;
      EmpDetailEntry detailEntry = null;

      try {
         // Open the database
         empDB = new EmployeeDB();
         empDB.openSharedRead();
                           
         // Create a dataset  
         empDetail = new EmpDetailDS(empDB);

         //Create an Entry for the dataset 
         detailEntry = new EmpDetailEntry(empDB, empDetail);
         detailEntry.initialize();

         // Read the dataset and display results 
         while(empDetail.readSerial(detailEntry)){
            detailEntry.display();
         }
         System.out.println("No more entries in dataset.");
         System.out.println("Normal termination.");
         System.exit(0);
      } catch (IMAGEException e2) {
         System.out.println(e2.toString());
      } catch (RemoteException e3) {
         e3.printStackTrace();
         System.out.println(e3.toString());
      } finally {
         if (empDB != null)
            empDB.close();
      }
      System.exit(0);
   }
}
