//import TurboIMAGE.*;
import com.hp.turboimage.*;

import java.io.*;
import java.net.*;
import java.rmi.RemoteException;

/** This class is used to access the EMPDTL dataset.  While it is easiest
 *  to think of Entry-derived classes as having a 1-to-1
 *  relationship with Datasets, in reality the relationship is
 *  to item lists.  Thus, if the same dataset is accessed using
 *  two different item lists, two Entry-derived classes will be
 *  required.<p>
 *
 * @see     TurboIMAGE.Entry
 * @version 2.1 March 1998
 * @author  Mike Yawn
 */
public class EmpDetailEntry extends EntryImpl {

   /** The class must include variables identifying
    *  each item to be accessed within the dataset.  
    *  These variable names are used in the AddElement
    *  calls done by initialize(), and also as keys to
    *  the getValue() and setValue methods of class Entry 
    *  which allow the contents of any field to be examined or set.
    */
   public String empNum     = "EMPLOYEE-NUMBER";
   public String firstName  = "FIRST-NAME";
   public String lastName   = "LAST-NAME";

   /** Constructor needs database, dataset */
   public EmpDetailEntry(EmployeeDB db, EmpDetailDS ds) throws RemoteException {
      super(db, ds);
   }

  /** This routine builds the list parameter, and also the
   *  information needed to translated data buffers between
   *  TurboIMAGE and Java formats.  The initElements call
   *  must always be done first, then all the AddElement
   *  calls, and finally lockElements.  See the documentation
   *  for class Entry for alternate versions of AddElement.
   */
  public void initialize() {
     initElements();
     addElement("EMPLOYEE-NUMBER");
     addElement("FIRST-NAME");
     addElement("LAST-NAME");
     lockElements();
  }
  
  /** Each Entry-derived class must implement a display()
   *  method to provide a quick-and-dirty way to display
   *  an Entry's contents.      
   */
   public void display() {
      try {
         System.out.println(getValue(empNum) + " " +
                            getValue(firstName) + " " +
                            getValue(lastName) 
                           );
      } catch (IMAGEException e) {
         System.out.println(e);
      }
   }
}
